@@ -1,4 +1,7 @@
 package Reflex::Object;
+BEGIN {
+  $Reflex::Object::VERSION = '0.004';
+}
 
 use Moose;
 with 'Reflex::Role::Object';
@@ -6,10 +9,8 @@ with 'Reflex::Role::Object';
 # Composes the Reflex::Role::Object into a class.
 # Does nothing of its own.
 
-no Moose;
-__PACKAGE__->meta()->make_immutable();
-
 1;
+# TODO - Document.
 
 __END__
 
@@ -17,6 +18,10 @@ __END__
 
 Reflex::Object - Base class for reactive objects.
 
+=head1 VERSION
+
+version 0.004
+
 =head1 SYNOPSIS
 
 	{
@@ -64,4 +69,4 @@ L<Reflex/OTHER CONTRIBUTORS>
 
 L<Reflex/COPYRIGHT AND LICENSE>
 
-=cut
+=cut
\ No newline at end of file
