@@ -1,4 +1,7 @@
 package Reflex::PID;
+BEGIN {
+  $Reflex::PID::VERSION = '0.004';
+}
 
 use Moose;
 extends qw(Reflex::Signal);
@@ -29,10 +32,8 @@ sub stop_watching {
 	$self->name(undef);
 }
 
-no Moose;
-__PACKAGE__->meta()->make_immutable();
-
 1;
+# TODO - Document.
 
 __END__
 
@@ -40,6 +41,10 @@ __END__
 
 Reflex::PID - Observe the exit of a subprocess, via handling SIGCHLD.
 
+=head1 VERSION
+
+version 0.004
+
 =head1 SYNOPSIS
 
 # Not a complete program.  Please see the source for
@@ -107,4 +112,4 @@ L<Reflex/OTHER CONTRIBUTORS>
 
 L<Reflex/COPYRIGHT AND LICENSE>
 
-=cut
+=cut
\ No newline at end of file
