@@ -1,4 +1,7 @@
 package Reflex::POE::Session;
+BEGIN {
+  $Reflex::POE::Session::VERSION = '0.004';
+}
 
 use Moose;
 extends 'Reflex::Object';
@@ -36,12 +39,13 @@ sub deliver {
 	foreach my $self (values %{$session_id_to_object{$sender_id}}) {
 		$self->emit(
 			event => $event,
-			args  => [ @$args ],
+			args  => { map { $_ => $args->[$_] } (0..$#$args) },
 		);
 	}
 }
 
 1;
+# TODO - Document.
 
 __END__
 
@@ -49,43 +53,46 @@ __END__
 
 Reflex::POE::Session - Observe events from a POE::Session object.
 
+=head1 VERSION
+
+version 0.004
+
 =head1 SYNOPSIS
 
-# Not a complete example.  Please see eg-13-irc-bot.pl in the examples
-# for a working one.
+# Not a complete example.
+# Please see eg-13-irc-bot.pl in the examples for one.
 
+	has poco_watcher => (
+		isa     => 'Reflex::POE::Session',
+		is      => 'rw',
+		traits  => ['Reflex::Trait::Observer'],
+		role    => 'poco',
+	);
 
-  has poco_watcher => (
-    isa     => 'Reflex::POE::Session',
-    is      => 'rw',
-    traits  => ['Reflex::Trait::Observer'],
-    role    => 'poco',
-  );
+	sub BUILD {
+		my $self = shift;
 
-  sub BUILD {
-    my $self = shift;
+		$self->component(
+			POE::Component::IRC->spawn(
+				nick    => "reflex_$$",
+				ircname => "Reflex Test Bot",
+				server  => "10.0.0.25",
+			) || die "Drat: $!"
+		);
 
-    $self->component(
-      POE::Component::IRC->spawn(
-        nick    => "reflex_$$",
-        ircname => "Reflex Test Bot",
-        server  => "10.0.0.25",
-      ) || die "Drat: $!"
-    );
+		$self->poco_watcher(
+			Reflex::POE::Session->new(
+				sid => $self->component()->session_id(),
+			)
+		);
 
-    $self->poco_watcher(
-      Reflex::POE::Session->new(
-        sid => $self->component()->session_id(),
-      )
-    );
-
-    $self->run_within_session(
-      sub {
-        $self->component()->yield(register => "all");
-        $self->component()->yield(connect  => {});
-      }
-    )
-  }
+		$self->run_within_session(
+			sub {
+				$self->component()->yield(register => "all");
+				$self->component()->yield(connect  => {});
+			}
+		)
+	}
 
 TODO - Either complete the example, or find a shorter one.
 
@@ -93,10 +100,10 @@ TODO - Either complete the example, or find a shorter one.
 
 Reflex::POE::Session allows a Reflex::Object to receive events from a
 specific POE::Session instance, identified by the session's ID.  In
-the future, it may also limit the events it may see, for better
+the future it may also limit the events it sees to allow better
 performance.
 
-TODO - Complete the documentatin.
+TODO - Complete the documentation.
 
 =head1 GETTING HELP
 
@@ -126,4 +133,4 @@ L<Reflex/OTHER CONTRIBUTORS>
 
 L<Reflex/COPYRIGHT AND LICENSE>
 
-=cut
+=cut
\ No newline at end of file
