@@ -1,4 +1,7 @@
 package Reflex::Signal;
+BEGIN {
+  $Reflex::Signal::VERSION = '0.004';
+}
 
 use Moose;
 extends qw(Reflex::Object);
@@ -100,10 +103,8 @@ sub DEMOLISH {
 	}
 }
 
-no Moose;
-__PACKAGE__->meta()->make_immutable();
-
 1;
+# TODO - Document.
 
 __END__
 
@@ -111,6 +112,10 @@ __END__
 
 Reflex::Signal - Generic signal observer and base class for specific ones.
 
+=head1 VERSION
+
+version 0.004
+
 =head1 SYNOPSIS
 
 TODO - Sorry, not yet.  This class works (see the source for
@@ -118,7 +123,7 @@ Reflex::PID, which extends it), but the API is not firm.
 
 =head1 DESCRIPTION
 
-Reflex::Signal is a generig signal observer.  Objects may use it to be
+Reflex::Signal is a general signal observer.  Objects may use it to be
 notified when the OS sends signals.  It may also be extended to handle
 nuanced semantics of more specific signals.
 
@@ -154,4 +159,4 @@ L<Reflex/OTHER CONTRIBUTORS>
 
 L<Reflex/COPYRIGHT AND LICENSE>
 
-=cut
+=cut
\ No newline at end of file
